import 'dart:collection';

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:share_it/share_it.dart';

void main() {
  const MethodChannel channel = MethodChannel(K.methodChannel);

  setUp(() {
    channel.setMockMethodCallHandler((MethodCall methodCall) async {
      switch (methodCall.method) {
        case K.iOSInvokeShareMethod:
          expect(methodCall.arguments is Map, true);
          final arguments = methodCall.arguments as LinkedHashMap<dynamic, dynamic>;
          expect(arguments['type'] != null, true);
          expect(arguments['content'] != null, true);

          if (arguments['type'] == IOSDataType.plainText.rawValue) {
            expect(arguments['type'], IOSDataType.plainText.rawValue);
            expect(arguments['content'], 'something');
          } else {
            expect(arguments['type'], IOSDataType.file.rawValue);
            expect(arguments['content'], 'somePath');
          }
          return true;
        case K.androidInvokeShareMethod:
          expect(methodCall.arguments is Map, true);
          final arguments = methodCall.arguments as LinkedHashMap<dynamic, dynamic>;
          expect(arguments['type'] != null, true);
          expect(arguments['content'] != null, true);
          expect(arguments['title'] != null, true);
          expect(arguments['shareAsPlainText'] != null, true);

          expect(arguments['shareAsPlainText'] == true || arguments['shareAsPlainText'] == false, true);

          expect(arguments['title'], 'a title');

          if (arguments['shareAsPlainText'] == true) {
            expect(arguments['type'], MIMEType.plainText.rawValue);
            expect(arguments['content'], 'something2');
          } else {
            expect(arguments['type'], MIMEType.image.rawValue);
            expect(arguments['content'], 'somePath2');
          }
          return true;
        default:
          fail("Incorrect method");
          return false;
      }
    });
  });

  tearDown(() {
    channel.setMockMethodCallHandler(null);
  });

  test(K.iOSInvokeShareMethod, () async {
    expect(await ShareIt.iOSText(content: 'something'), true);
  });

  test(K.androidInvokeShareMethod, () async {
    expect(await ShareIt.androidText(content: 'something2', title: 'a title'), true);
  });

  test('${K.iOSInvokeShareMethod}file', () async {
    expect(await ShareIt.iOSFile(dataType: IOSDataType.file, path: 'somePath'), true);
  });

  test('${K.androidInvokeShareMethod}file', () async {
    expect(await ShareIt.androidFile(mimeType: MIMEType.image, path: 'somePath2', title: 'a title'), true);
  });
}
